import  {
  select, 
  csv, 
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft, 
  axisBottom,
  area,
  format,
  curveBasis
} from 'd3';
const svg = select("svg");
const width = +svg.attr("width"),
      height = +svg.attr("height");

const render = data => {
  const xValue = d => d.year;
  const xAxisLabel = "Time";
  const yValue = d => d.population;
  const yAxisLabel = "Population";  
  const title = "World Population";
  const margin = { top: 80, left: 100, bottom: 65, right: 40}
  const innerWidth = width - margin.left - margin.right; 
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice()
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10)
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice()
  
  const yAxisTickFormat = number => 
  	format('.1s')(number)
  		.replace("G", "B");
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  	.tickFormat(yAxisTickFormat)
  
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left}, ${margin.top})`)
  
  const yAxisG = g.append("g").call(yAxis)
	yAxisG.selectAll(".domain").remove();
  yAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('x', -innerHeight / 2)
  	.attr('y', -60)
  	.attr('transform', "rotate(-90)")
  	.attr('text-anchor', 'middle')
  	.attr('fill', 'black')
  	.text(yAxisLabel);
  	
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('y', 55)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))  
  	.curve(curveBasis)
  
  g.append("path")
  	.attr("class", "line-path")
  	.attr("d", areaGenerator(data));
  
  svg.append("text")
  	.attr("y", 50)
  	.attr("x", width / 2)
  	.attr("text-anchor", "middle")
  	.text(title)
}

csv('world_population_2019.csv')
	.then(data => {
      data.forEach(d => {
        d.year = new Date(d.year);
        d.population = +d.population;
      });
    	render(data);
  	});